==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/adm/model/OciResourceVulnerabilityAuditSource.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.adm.model;

/**
 * OCI resource source for the vulnerability audit. <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20220421")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = OciResourceVulnerabilityAuditSource.Builder.class)
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "type")
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class OciResourceVulnerabilityAuditSource extends VulnerabilityAuditSource {
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        /**
         * The Oracle Cloud identifier
         * ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the
         * OCI resource that triggered the vulnerability audit.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("ociResourceId")
        private String ociResourceId;

        /**
         * The Oracle Cloud identifier
         * ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the
         * OCI resource that triggered the vulnerability audit.
         *
         * @param ociResourceId the value to set
         * @return this builder
         */
        public Builder ociResourceId(String ociResourceId) {
            this.ociResourceId = ociResourceId;
            this.__explicitlySet__.add("ociResourceId");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public OciResourceVulnerabilityAuditSource build() {
            OciResourceVulnerabilityAuditSource model =
                    new OciResourceVulnerabilityAuditSource(this.ociResourceId);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(OciResourceVulnerabilityAuditSource model) {
            if (model.wasPropertyExplicitlySet("ociResourceId")) {
                this.ociResourceId(model.getOciResourceId());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    @Deprecated
    public OciResourceVulnerabilityAuditSource(String ociResourceId) {
        super();
        this.ociResourceId = ociResourceId;
    }

    /**
     * The Oracle Cloud identifier
     * ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the OCI
     * resource that triggered the vulnerability audit.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("ociResourceId")
    private final String ociResourceId;

    /**
     * The Oracle Cloud identifier
     * ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the OCI
     * resource that triggered the vulnerability audit.
     *
     * @return the value
     */
    public String getOciResourceId() {
        return ociResourceId;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("OciResourceVulnerabilityAuditSource(");
        sb.append("super=").append(super.toString(includeByteArrayContents));
        sb.append(", ociResourceId=").append(String.valueOf(this.ociResourceId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof OciResourceVulnerabilityAuditSource)) {
            return false;
        }

        OciResourceVulnerabilityAuditSource other = (OciResourceVulnerabilityAuditSource) o;
        return java.util.Objects.equals(this.ociResourceId, other.ociResourceId)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.ociResourceId == null ? 43 : this.ociResourceId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.63.1-sources.jar: com/oracle/bmc/adm/model/OciResourceVulnerabilityAuditSource.java <==
/**
 * Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.adm.model;

/**
 * OCI resource source for the vulnerability audit. <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20220421")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = OciResourceVulnerabilityAuditSource.Builder.class)
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "type")
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class OciResourceVulnerabilityAuditSource extends VulnerabilityAuditSource {
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        /**
         * The Oracle Cloud identifier
         * ([OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the
         * OCI resource that triggered the vulnerability audit.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("ociResourceId")
        private String ociResourceId;

        /**
         * The Oracle Cloud identifier
         * ([OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the
         * OCI resource that triggered the vulnerability audit.
         *
         * @param ociResourceId the value to set
         * @return this builder
         */
        public Builder ociResourceId(String ociResourceId) {
            this.ociResourceId = ociResourceId;
            this.__explicitlySet__.add("ociResourceId");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public OciResourceVulnerabilityAuditSource build() {
            OciResourceVulnerabilityAuditSource model =
                    new OciResourceVulnerabilityAuditSource(this.ociResourceId);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(OciResourceVulnerabilityAuditSource model) {
            if (model.wasPropertyExplicitlySet("ociResourceId")) {
                this.ociResourceId(model.getOciResourceId());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    @Deprecated
    public OciResourceVulnerabilityAuditSource(String ociResourceId) {
        super();
        this.ociResourceId = ociResourceId;
    }

    /**
     * The Oracle Cloud identifier
     * ([OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the OCI
     * resource that triggered the vulnerability audit.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("ociResourceId")
    private final String ociResourceId;

    /**
     * The Oracle Cloud identifier
     * ([OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the OCI
     * resource that triggered the vulnerability audit.
     *
     * @return the value
     */
    public String getOciResourceId() {
        return ociResourceId;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("OciResourceVulnerabilityAuditSource(");
        sb.append("super=").append(super.toString(includeByteArrayContents));
        sb.append(", ociResourceId=").append(String.valueOf(this.ociResourceId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof OciResourceVulnerabilityAuditSource)) {
            return false;
        }

        OciResourceVulnerabilityAuditSource other = (OciResourceVulnerabilityAuditSource) o;
        return java.util.Objects.equals(this.ociResourceId, other.ociResourceId)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.ociResourceId == null ? 43 : this.ociResourceId.hashCode());
        return result;
    }
}
